#
# spec file for package kodi
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#
#

# Please edit kodi.spec and kodi.changes only. *-noX.* files are generated from
# kodi.* files with the pre_checkin.sh script
%define kodi_version Leia
%define _kodi_addons_dir %{_datadir}/kodi/addons
%define dev_build 1
# kodi can be built without X support when openGL ES is used (mainly used on ARM boards used as media center)
%define noX_build 0
%if %{noX_build}
# no X build needs openGL ES
%bcond_with enable_opengl
%bcond_without enable_opengles
%else
%ifarch %arm armv6l armv6hl
%bcond_with enable_opengl
%bcond_without enable_opengles
%else
%bcond_without enable_opengl
%bcond_with enable_opengles
%endif
%endif

%define kodi_platform none
%define kodi_player none

Name:           kodi.binary-addons
Version:        18.9
Release:        5.1
Summary:        Binary Addons for Kodi
License:        GPL-2.0+ and GPL-3.0+
Group:          Productivity/Multimedia/Video/Players
Url:            http://kodi.tv/
Source0:        https://github.com/xbmc/xbmc/archive/%{version}-%{kodi_version}.tar.gz
Source1:        kodi.binary-addons.spec.packages.inc
Source2:        kodi.binary-addons.spec.files.inc
Source3:        kodi.binary-addons.tar
Source4:        repo-binary-addons.%{kodi_version}.tar.bz2
Source5:        kodi-platform-e8574b8.tar.gz
Source20:       http://mirrors.kodi.tv/build-deps/sources/rapidxml-1.13.zip
Source21:       rapidxml.cmake
Patch1:         cmake-binary-addons.patch
Patch2:         addon-helpers_lib64.patch
# PATCH-PACKMAN kodi.binary-addons-audiodecoder.ncsf-gcc5.3.patch - fixes compiling of audiodecoder.ncsf with gcc > 4.8, suse_version >= 1320
#Patch3:         kodi.binary-addons-audiodecoder.ncsf-gcc5.3.patch
# PATCH-PACKMAN kodi.binary-addons-screensavers.rsxs-upstream-stdbool_h.patch - fixes compiling of screensavers.rsxs with gcc > 4.8, suse_version >= 1320
#Patch4:         kodi.binary-addons-screensavers.rsxs-upstream-stdbool_h.patch
#Patch5:         lib555-missing-xlocale.patch
#Patch6:         pvr.stalker-gcc7.patch
# PATCH-PACKMAN kodi.binary.addons-noreturnfromnonvoid.patch - davejplater@gmail.com - Suddenly an rpmlint no return from nonvoid has appeared after taglib was updated.
Patch7:         kodi.binary.addons-noreturnfromnonvoid.patch
#Patch8:         kodi.binary-addons-screensavers.rsxs-host-toolchain.patch
Patch9:         kodi.binary-addons-vfs.sacd.no-int-conversion.patch

BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  ccache
BuildRequires:  cmake
BuildRequires:  fdupes
%if 0%{?suse_version} > 1320 && 0%{?sle_version} == 0
BuildRequires:	gcc9
BuildRequires:  gcc9-c++
%else
BuildRequires:  gcc8
BuildRequires:  gcc8-c++
%endif
%if %{noX_build}
BuildRequires:  kodi-noX-devel = %{version}
%else
BuildRequires:  kodi-devel = %{version}
%endif
BuildRequires:  giflib-devel
BuildRequires:  gli-devel
BuildRequires:  cmake(glm) >= 0.9.9
BuildRequires:  jsoncpp-devel
BuildRequires:	nlohmann_json-devel
BuildRequires:  tinyxml-devel
BuildRequires:  libhdhomerun-devel
BuildRequires:  liblz4-devel
BuildRequires:  libmp3lame-devel
BuildRequires:  libnfs-devel
BuildRequires:  libraw-devel
BuildRequires:  libsmbclient-devel
BuildRequires:  libSOIL-devel
BuildRequires:  libstdc++-devel
BuildRequires:  libtiff-devel
BuildRequires:  libtool
BuildRequires:  libxml2-devel
BuildRequires:  lzo-devel
BuildRequires:  nlohmann_json-devel
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(flac)
BuildRequires:  pkgconfig(fluidsynth)
BuildRequires:  pkgconfig(libarchive) >= 3.3.2
BuildRequires:	pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libmodplug)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libprojectM)
BuildRequires:  pkgconfig(librtmp)
BuildRequires:  pkgconfig(libssh)
BuildRequires:  pkgconfig(libssl)
BuildRequires:  pkgconfig(p8-platform)
BuildRequires:  pkgconfig(tinyxml2)
BuildRequires:  pkgconfig(vorbis)
BuildRequires:  rapidjson-devel

# kodi needs the same libtag version which was used to build against
%requires_eq    libtag1
%if !%{noX_build}
BuildRequires:  xorg-x11-devel
%endif
%if %{with enable_opengl}
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glew)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(vdpau)
%endif

%if %{with enable_opengles}
%if %{kodi_platform} == "none"
BuildRequires:  Mesa-libEGL-devel
BuildRequires:  Mesa-libGLESv2-devel
%else
%if %{kodi_platform} == "raspberry-pi" || %{kodi_platform} == "raspberry-pi2"
BuildRequires:  raspberrypi-userland-devel
%endif
%endif
%endif

# glxinfo is needed to check hw accel
%if 0%{?suse_version} >= 1220
%if !%{noX_build}
Requires:       Mesa-demo-x
Requires:       xdpyinfo
%endif
%endif

BuildRoot:      %{_tmprath}/%{name}-%{version}-build
ExcludeArch:    ppc64
Requires:       kodi = %{version}
#Requires:       libjsoncpp1

%description
Binary Addons for Kodi Media Center

%include %{SOURCE1}

%prep
%setup -q -n xbmc-%{version}-%{kodi_version}
%patch1
%patch2

pushd cmake/addons
tar xvf %{SOURCE3}
mkdir -pv build/bootstrap/binary-addons/src
cp -v %{SOURCE4} build/bootstrap/binary-addons/src

# Remove deps that are already installed using BuildRequires
rm -rf depends/common/{p8-platform,tinyxml}
rm -f  depends/common/kodi-platform/deps.txt
cp -v %{SOURCE5} depends/common/kodi-platform
echo "kodi-platform file://../../../../../cmake/addons/depends/common/kodi-platform/kodi-platform-e8574b8.tar.gz" > depends/common/kodi-platform/kodi-platform.txt
mkdir -pv depends/common/rapidxml
cp -v %{SOURCE20} depends/common/rapidxml
cp -v %{SOURCE21} depends/common/rapidxml/CMakeLists.txt
echo "rapidxml file://../../../../../cmake/addons/depends/common/rapidxml/rapidxml-1.13.zip" > depends/common/rapidxml/rapidxml.txt
echo "c3f0b886374981bb20fabcf323d755db4be6dba42064599481da64a85f5b3571" > depends/common/rapidxml/rapidxml.sha256
popd

%build
sed -i~ 's/@@@_libdir@@@/%{_lib}/' cmake/scripts/common/AddonHelpers.cmake
diff -u cmake/scripts/common/AddonHelpers.cmake~ cmake/scripts/common/AddonHelpers.cmake && exit 0


# Tumbleweed and Factory have GCC 5.x ATM (20160309), source needs patching for this
#%if 0%{?suse_version} > 1320
  # patch audiodecoders.ncsf
  #patch -p0 < %%{PATCH3}
  # patch screensavers.rsxs
  #patch screensavers.rsxs/lib/rsxs-1.0/lib/stdbool.in.h %{PATCH4}
  #patch -up0 --verbose < %{PATCH5}
  #patch -up4 --verbose < %{PATCH6}
#%endif

# fake buildtime in audiodecoder.qsf
FAKE_BUILDDATE=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%b %%e %%Y')
FAKE_BUILDTIME=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%H:%%M:%%S')
#for file in audiodecoder.qsf/lib/Highly_Quixotic/Core/qsound.c \
#            audiodecoder.ssf/lib/Highly_Theoretical/Core/Starscream/star.c \
#            audiodecoder.ssf/lib/Highly_Theoretical/Core/sega.c \
#            audiodecoder.timidity/lib/timidity/timidity/speex_a.c; do
#  sed -i -e "s/__DATE__/\"$FAKE_BUILDDATE\"/" -e "s/__TIME__/\"$FAKE_BUILDTIME\"/" $file
#done
#patch -p 0 < %{PATCH7}
#make VERBOSE=1 %{?_smp_mflags}

%if 0%{?suse_version} > 1320 && 0%{?sle_version} == 0
 export CC=gcc-9
 export CXX=g++-9
%else
 export CC=gcc-8
 export CXX=g++-8
%endif

pushd tools/depends/target/binary-addons
mkdir -p native
%cmake \
    ../../../../../cmake/addons \
%if %{dev_build}
    -DVERBOSE=ON \
%endif
    -DCMAKE_C_COMPILER=$CC \
    -DCMAKE_CXX_COMPILER=$CXX \
%ifarch %{ix86}
    -DCMAKE_C_FLAGS=-mavx \
%endif
    -DBUILD_DIR=build \
    -DNEED_SUDO=FALSE \
    -DAPP_LIB_DIR=%{buildroot}%{_libdir}/kodi \
    -DCMAKE_INSTALL_LIBDIR=%{buildroot}%{_libdir}/kodi \
    -DCMAKE_INSTALL_PREFIX=%{buildroot}%{_prefix} \
    -DADDONS_TO_BUILD="all" 

popd

# Patching addons after being unpacked
pushd cmake/addons
patch -up2 --verbose -i %{PATCH7}
#patch -up0 --verbose -i %{PATCH8}
patch -up2 --verbose -i %{PATCH9}
popd

pushd tools/depends/target/binary-addons/build
# Workaround for cmake 3.18 issue with copy_if_different issue adding "" at the end of line
sed -i -e 's#""##' depends/CMakeFiles/rapidxml.dir/build.make
make -O %{?_smp_mflags} VERBOSE=1 CC=$CC CXX=$CXX
#%{?_smp_mflags}
%install

%fdupes %{buildroot}

%files
%defattr(-,root,root)
%dir %{_libdir}/kodi
%dir %{_datadir}/kodi
%{_libdir}/kodi/PrepareEnv.cmake

%include %{SOURCE2}

%changelog
* Tue Oct 27 2020 manfred.h@gmx.net
- Rebuild kodi.binary-addons.tar, repo-binary-addons.Leia.tar.bz2,
  kodi.binary-addons.spec.files.inc, kodi.binary-addons.spec.packages.inc
* Mon Oct 26 2020 manfred.h@gmx.net
- Version update to Kodi 18.9 Leia
- Regenerate patch "cmake-binary-addons.patch"
* Mon Aug  3 2020 sagiben@gmail.com
- Add workaround for cmake 3.18 issue with copy_if_different issue
  adding "" at the end of line
* Sun Aug  2 2020 manfred.h@gmx.net
- download_binary-addons.sh: No pvr addons need to be patched using
  FindJsonCpp.cmake.patch anymore; set JSONCPP_PATCH to empty string.
- Rebuild kodi.binary-addons.tar, repo-binary-addons.Leia.tar.bz2,
  kodi.binary-addons.spec.files.inc, kodi.binary-addons.spec.packages.inc
* Fri Jul 31 2020 manfred.h@gmx.net
- Version update to Kodi 18.8 Leia
- Rebuild kodi.binary-addons.tar, repo-binary-addons.Leia.tar.bz2,
  kodi.binary-addons.spec.files.inc, kodi.binary-addons.spec.packages.inc
* Fri May 22 2020 manfred.h@gmx.net
- Version update to Kodi 18.7 Leia
* Mon Mar  9 2020 manfred.h@gmx.net
- Version update to Kodi 18.6 Leia
* Wed Nov 20 2019 sagiben@gmail.com
- Version update to Kodi 18.5 Leia
* Thu Oct 31 2019 manfred.h@gmx.net
- Use gcc-9/g++-9 on Tumbleweed/Factory.
* Wed Sep  4 2019 sagiben@gmail.com
- Version update to Kodi 18.4 Leia
* Fri Jul 12 2019 sagiben@gmail.com
- re-enable
  * pvr.iptvsimple
  * pvr.zattoo
  * pvr.teleboy
* Mon Jun 24 2019 sagiben@gmail.com
- Version update to Kodi 18.3 Leia
* Tue Jun 11 2019 manfred.h@gmx.net
- *.spec: Add additional flag to allow building for 32-bit Intel
  architecture; thanks go to Giacomo Comes <comes@naic.edu>!
* Wed Apr 24 2019 manfred.h@gmx.net
- Use gcc8 for building.
- kodi.binary.addons-noreturnfromnonvoid.patch: Re-generate.
- Re-enable patch7 (kodi.binary.addons-noreturnfromnonvoid.patch).
* Wed Apr 24 2019 manfred.h@gmx.net
- download_binary-addons.sh: Use "Leia" branch
  * Rebuild kodi.binary-addons.tar, repo-binary-addons.Leia.tar.bz2,
    kodi.binary-addons.spec.files.inc, kodi.binary-addons.spec.packages.inc
  * cmake-binary-addons.patch: Fix repo-binary-addons.git entry
- Disable Patch8 (kodi.binary-addons-screensavers.rsxs-host-toolchain.patch)
- Change BuildRequires:  libjpeg8-devel with BuildRequires: pkgconfig(libjpeg)
- Change BuildRequires:  libopenssl-devel with BuildRequires: pkgconfig(libssl)
- Add BuildRequires:  gli-devel, glm-devel, libtiff-devel
- repo-binary-addons-Leia-disabled.txt: Add new file specific to the "Leia"
  branch for disabling addons which don't build.
- Disable imagedecoder.heif as it requires libde265 which we don't (yet) have.
- Disable screensavers.rsxs: Our latest version of glm-devel does not build
* Tue Apr 23 2019 manfred.h@gmx.net
- Version update to Kodi 18.2 Leia
* Wed Feb 20 2019 manfred.h@gmx.net
- Version update to Kodi 18.1 Leia
- Rebuild kodi.binary-addons.tar, repo-binary-addons.Leia.tar.bz2,
  kodi.binary-addons.spec.files.inc, kodi.binary-addons.spec.packages.inc
- Disable screensaver.asterwave and screensaver.cpblobs; both need
  glm-devel, but this does not compile for screensaver.cpblobs.
* Mon Feb  4 2019 manfred.h@gmx.net
- Comment patches 3..7, as they are unused.
* Wed Jan 30 2019 manfred.h@gmx.net
- Update to Kodi 18.0 Leia
- Rebuild kodi.binary-addons.tar, kodi.binary-addons.spec.files.inc,
  kodi.binary-addons.spec.packages.inc
* Sat Jan 19 2019 manfred.h@gmx.net
- Add BuildRequires: nlohmann_json-devel
- Re-enable pvr.vuplus
- Rebuild kodi.binary-addons.tar, kodi.binary-addons.spec.files.inc,
  kodi.binary-addons.spec.packages.inc
* Sat Dec 22 2018 davejplater@gmail.com
- Fixed build failure due to no return in non void function error
  which suddenly appeared when taglib was updated, with
  kodi.binary.addons-noreturnfromnonvoid.patch.
* Fri Dec 22 2017 olaf@aepfle.de
- Version update to Kodi 17.6 Krypton
* Sat Oct 28 2017 sagiben@gmail.com
- Version update to Kodi 17.5 Krypton
* Wed Sep 27 2017 davejplater@gmail.com
- Added patch lib555-missing-xlocale.patch xlocale.h has been
  depreciated for a long time and is no longer provided in
  tumbleweed.
- Added pvr.stalker-gcc7.patch to fix gcc7 build issues.
- Refreshed addon-helpers_lib64.patch
* Wed Aug 23 2017 sagiben@gmail.com
- Version update to Kodi 17.4 Krypton
* Fri May 26 2017 sagiben@gmail.com
- Version update to Kodi 17.3 Krypton
  A minor bug fix and security release
* Tue Mar 21 2017 sagiben@gmail.com
- Version update to Kodi 17.1 Krypton
* Thu Feb 16 2017 sagiben@gmail.com
- Version update to Kodi 17.0 Krypton
  http://kodi.wiki/view/Kodi_v17_(Krypton)_changelog
* Sat Aug  6 2016 olaf@aepfle.de
- Adjust BuildRequires libhdhomerun-devel
  Sun Apr 24 13:06:49 UTC 2016 - sagiben at gmail dot com
- Version update to Kodi 16.1 Jarvis
  https://kodi.tv/kodi-16-1-jarvis-mark-xvi
* Wed Mar  9 2016 guillaume@opensuse.org
- Fix noX builds
* Wed Mar  9 2016 obs@botter.cc
- fix compiling of audiodecoder.ncsf and screensavers.rsxs with
  gcc 5.x (Tumbleweed and Factory)
- replace __DATE__ in audiodecoder.qsf, audiodecoder.ssf and
  audiodecoder.timidity
  Sun Feb 14 10:17:23 UTC 2016 - sagiben at gmail.com
- Separate kodi.binary addon package from Kodi
